#!/usr/bin/python

"""
This file is part of Visuse.

Copyright (C) 2010 Jose Luis Lopez Pino jllopezpino@gmail.com

Visuse is free software: you can redistribute it and/or modify
it under 
the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Visuse is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Visuse.  If not, see <http://www.gnu.org/licenses/>.

"""

import gdata.photos.service
import gdata.media
import gdata.geo
from classes import *
import config
from difflib import SequenceMatcher


class Picasa(Result, ImageResult):
	def __init__(self, name, url, thumbnail, summary, tags):
		ImageResult.__init__(self, name, url, thumbnail)
		self.summary = summary
		self.tags = tags
		
	def estimateRating(self, search_terms):
		name_point = SequenceMatcher(None, self.name, search_terms).real_quick_ratio()
		summary_point = SequenceMatcher(None, self.summary, search_terms).real_quick_ratio()
		tags_point = SequenceMatcher(None, self.tags, search_terms).real_quick_ratio()
		estimated_rating = 0.8 * name_point + 0.2 * summary_point + 0.2 * tags_point
		self.rating = max(self.rating, estimated_rating);
		self.rating = min(1, self.rating);



class SearchPicasa(SearchModule):
	def __init__(self):
		SearchModule.__init__(self)

		
	def search(self, search_terms):
		gd_client = gdata.photos.service.PhotosService()

		photos = gd_client.SearchCommunityPhotos(search_terms, limit=config.picasa_limit)
		for iterador in photos.entry:
			self.add(iterador)
		
		for n in range(0, len(self.resultList)):
			self.resultList[n].estimateRating(search_terms)
		
		return self.resultList
	

	def add(self, entry):
		if entry.summary.text:
			summary = entry.summary.text
		else:
			summary = ""
		if entry.media.keywords:
			tags =  entry.media.keywords.text
		else:
			tags = ""
		
		self.resultList.append(Picasa( \
			entry.title.text, \
			entry.content.src, \
			entry.media.thumbnail[-1].url, \
			summary, \
			tags, \
		))


#~ s = SearchPicasa()
#~ s.search("molina")
#~ print unicode(s).encode("iso-8859-2", "replace")
